@@ -39,8 +39,7 @@ def split_data(
                 X,
                 y, 
                 test_size=test_size, 
-                random_state=random_state, 
-                stratify=y
+                random_state=random_state
             ) 
     else:
         X_train, y_train = X, y
@@ -58,8 +57,7 @@ def split_data(
     X_train, X_val, y_train, y_val = train_test_split(
         X_train,
         y_train,
-        random_state=0,
-        stratify=y_train
+        random_state=0
     )
     
     if not isinstance(X_train, torch.Tensor):
